@@ -11,7 +11,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 917 2008-05-06 00:56:53Z pronovic $
+# Revision : $Id: release.py 929 2008-11-15 18:16:08Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -34,7 +34,7 @@ Provides location to maintain version information.
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
 COPYRIGHT   = "2004-2008"
-VERSION     = "2.18.0"
-DATE        = "05 May 2008"
+VERSION     = "2.19.1"
+DATE        = "15 Nov 2008"
 URL         = "http://cedar-backup.sourceforge.net/"
 
